<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de_DE">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Face ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifikation erfolgreich</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifikation fehlgeschlagen, nur noch ein Versuch übrig</numerusform><numerusform>Verifikation fehlgeschlagen, noch %1 Versuche</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifizierung felgeschlagen, nurmehr ein Versuch möglich</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Face-ID verifizieren</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Face-ID gesperrt, bitte Passwort benützen</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Gerät nicht verfübar!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Ihren Fingerabdruck verifizieren</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifizierung erfolgreich</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifikation fehlgeschlagen, nur noch ein Versuch möglich</numerusform><numerusform>Verifizierung fehlgeschlagen, noch %n Versuche</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifizierung fehlgeschlagen, nur noch ein Versuch möglich</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Fingerabdruck gesperrt, bitte Passwort benutzen</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Iris-ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verifizierung erfolgreich</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifizierung fehlgeschlagen, noch %n Versuche übrig</numerusform><numerusform>Verifizierung fehlgeschlagen, noch %n Versuche</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifizierung fehlgeschlagen, nur noch ein Versuch möglich</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Iris-ID verifizieren</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Iris-ID gesperrt, bitte Passwort benützen</translation>
    </message>
</context>
<context>
    <name>AuthPasskey</name>
    <message>
        <source>Please plug in the security key</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification successful</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Verification failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Identifying the security key</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verifizierung erfolgreich</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifizierung fehlgeschlagen, noch %n Versuche übrig</numerusform><numerusform>Verifizierung fehlgeschlagen, noch %1 Versuche übrig</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifikation fehlgeschlagen, nur noch ein Versuch möglich</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Falsches Passwort</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Bitte in 1 Minute nochmals versuchen</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Bitte in %1 Minuten nochmals versuchen</numerusform><numerusform>Bitte in %n Minuten nochmals versuchen</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Passwort zurücksetzen</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Passwort vergessen?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Bitte in 1 Minute nochmals versuchen</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Bitte in %1 Minuten nochmals versuchen</numerusform><numerusform>Bitte in %n Minuten nochmals versuchen</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Passwort zurücksetzen</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Passwort vergessen?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verifizierung erfolgreich</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verifizierung fehlgeschlagen, noch %1 Versuche übrig</numerusform><numerusform>Verifizierung fehlgeschlagen, noch %1 Versuche</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verifizierung fehlgeschlagen, nur noch ein Versuch möglich</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Falsche PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey wird benötigt</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>PIN eingeben</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Bitte in %1 Minute(n) nochmals versuchen</numerusform><numerusform>Bitte in %n Minute(n) nochmals versuchen</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Bitte in 1 Minute nochmals versuchen</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Bitte in %1 Minuten nochmals versuchen</numerusform><numerusform>Bitte in %n Minuten nochmals versuchen</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>Ihr Passwort wird in %n Tagen abgelaufen sein, bitte zeitig erneuern</numerusform><numerusform>Ihr Passwort wird in %n Tagen ablaufen, bitte zeitig erneuern</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Terminal locked, please contact administrator</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DeepinAuthFramework</name>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Falsches Konto</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Falsches Passwort</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>The reason of inhibit.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LighterGreeter</name>
    <message>
        <source>Standard Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Bildschirm sperren</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Bildschirm sperren fehlgeschlagen</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Fingerabdruck-Verifizierung abgelaufen, bitte tippen Sie ihr Passwort ein</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Fingerabdrücke stimmen nicht überein</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Die obigen Benutzer sind noch angemeldet und Daten würden beim Herunterfahren verloren gehen, sind Sie sicher, dass Sie herunterfahren möchten?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Die obigen Benutzer sind noch angemeldet und Daten würden beim erneuten Hochfahren verloren gehen, sind Sie sicher, dass Sie herunterfahren möchten?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Neu Booten</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Abschalten</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Ruhezustand</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Sperren</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Abmelden</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Benutzer wechseln</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>System wechseln</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Aktualisieren und herunterfahren</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Aktualisieren und neustarten</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>System-Monitor starten</translation>
    </message>
</context>
<context>
    <name>UdcpMFALoginWidget</name>
    <message>
        <source>发送验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入手机号</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>获取验证码</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>Update</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation>Bitte ans Stromnetz anschließen und dann Aktualisierungen installieren</translation>
    </message>
</context>
<context>
    <name>UsersWithTheSameName</name>
    <message>
        <source>Return</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please select the account for login</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Local Account</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Domain Account</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Die Programme verhindern ein Herunterfahren des Computers, und ein Erzwingen kann Datenverlust bedeuten.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Um das Programm zu beenden, klicken Sie auf Abbrechen und beenden dann das Programm.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>DIe Programme verhindern das erneute Hochfahren des Computers, ein Erzwingen kann Datenverlust bedeuten</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>DIe Programme verhindern das Abschalten des Computers, ein Erzwingen kann Datenverlust bedeuten.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>DIe Programme verhindern den Ruhezustand des Computers, ein Erzwingen kann Datenverlust bedeuten</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>DIe Programme verhindern das Abmelden des Computers, ein Erzwingen kann Datenverlust bedeuten</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Neu Hochfahren</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Abschalten</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Ruhezustand</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Abmelden</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Sind Sie sicher, dass Sie sie herunterfahren möchten?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Sind Sie sicher, dass Sie sie neu hochfahren möchten?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Sind Sie sicher, dass Sie sie sich abmelden möchten?</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Aktualisieren und herunterfahren</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Aktualisieren und neustarten</translation>
    </message>
    <message>
        <source>Closing the programs and shutting down, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and rebooting, please wait...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Closing the programs and logging out, please wait...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::AssistLoginWidget</name>
    <message>
        <source>Automatic login</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Anschalten</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Abschalten</translation>
    </message>
</context>
</TS>